"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const log_level_1 = require("./log-level");
/**
 * Implementation of ILogger
 */
class Logger {
    /**
     * Create new instance of Logger
     * @param logLevel {LogLevel} Logging level
     */
    constructor(logLevel = log_level_1.LogLevel.Information) {
        this.LogLevel = logLevel;
    }
    /**
     * Logs with Debug LogLevel
     * @param log {any} Message to log
     */
    Debug(message) {
        this.Log(log_level_1.LogLevel.Debug, message);
    }
    /**
     * Logs with Error LogLevel
     * @param log {any} Message to log
     */
    Error(message) {
        this.Log(log_level_1.LogLevel.Error, message);
    }
    /**
     * Logs with Information LogLevel
     * @param log {any} Message to log
     */
    Information(message) {
        this.Log(log_level_1.LogLevel.Information, message);
    }
    /**
     * Logs with Trace LogLevel
     * @param log {any} Message to log
     */
    Trace(message) {
        this.Log(log_level_1.LogLevel.Trace, message);
    }
    /**
     * Logs with Warning LogLevel
     * @param log {any} Message to log
     */
    Warning(message) {
        this.Log(log_level_1.LogLevel.Warning, message);
    }
    /**
     * Logs with given LogLevel
     * @param level {LogLevel} Logging level to log at
     * @param log {any} Message to log
     */
    Log(level, message) {
        if (this.LogLevel > log_level_1.LogLevel.Off && this.LogLevel >= level) {
            // create the message to log
            const logMessage = `[${log_level_1.LogLevel[level].toUpperCase()}]-${message}`;
            switch (level) {
                case log_level_1.LogLevel.Error:
                    console.error(logMessage);
                    break;
                case log_level_1.LogLevel.Warning:
                    console.warn(logMessage);
                    break;
                default:
                    console.log(logMessage);
                    break;
            }
        }
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map